==> breeze_website_builder_6.5.0.tar.gz: manage/delete_page_select.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 9/9/2008
// Revised: 2/10/2012	ELL
// Added table prefix handling.
	
	include ("check_session.php");
?>
<!DOCTYPE html>
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>Delete Page Select | Breeze Website Builder</title>
<link rel="stylesheet" href="theme/<?php echo $theme; ?>/manager.css" type="text/css">

<style type="text/css">
#help_button	{	
	position:relative;
	display:block;
	top:-15px;
	left:215px;
	height:31px;
	width:31px;
	z-index:100;
}
#delete_page_btn	{	width:110px;	}
#delete_blog_btn	{	width:110px;	}
</style>

<script language="javascript" type="text/javascript" src="js/browser_detect.js"></script>
<script language="javascript" type="text/javascript" src="js/mouse_position.js"></script>
<script language="javascript" type="text/javascript" src="js/popup_msg.js"></script>
<script language="javascript" type="text/javascript" src="js/delete_page_select.js"></script>

<script>
<?php
	echo "	var YES_WORD = \"" . YES_WORD . "\";\n";
	echo "	var NO_WORD = \"" . NO_WORD . "\";\n";
	echo "	var DELETE_PAGE_OR_BLOG_DELETE_BLOG_CONFIRM_1_MSG = \"" . DELETE_PAGE_OR_BLOG_DELETE_BLOG_CONFIRM_1_MSG . "\";\n";
	echo "	var DELETE_PAGE_OR_BLOG_DELETE_BLOG_CONFIRM_2_MSG = \"" . DELETE_PAGE_OR_BLOG_DELETE_BLOG_CONFIRM_2_MSG . "\";\n";
	echo "	var DELETE_PAGE_OR_BLOG_DELETE_PAGE_CONFIRM_1_MSG = \"" . DELETE_PAGE_OR_BLOG_DELETE_PAGE_CONFIRM_1_MSG . "\";\n";
	echo "	var DELETE_PAGE_OR_BLOG_DELETE_PAGE_CONFIRM_2_MSG = \"" . DELETE_PAGE_OR_BLOG_DELETE_PAGE_CONFIRM_2_MSG . "\";\n";
	echo "	var DELETE_PAGE_OR_BLOG_RECALL_PLUGIN_CONFIRM_1_MSG = \"" . DELETE_PAGE_OR_BLOG_RECALL_PLUGIN_CONFIRM_1_MSG . "\";\n";
	echo "	var DELETE_PAGE_OR_BLOG_RECALL_PLUGIN_CONFIRM_2_MSG = \"" . DELETE_PAGE_OR_BLOG_RECALL_PLUGIN_CONFIRM_2_MSG . "\";\n";
	
	echo "	var BWB_BASE_DIR = \"" . BWB_BASE_DIR . "\";\n";
	echo "	var BWB_WEBPAGE_DIR = \"" . BWB_WEBPAGE_DIR . "\";\n";
?>
</script>
</head>

<body>
<div class="button_heading_sub_level_1" id="delete_page_blog_heading"><div class="button_heading_text_sub_level_1"><?php echo DELETE_PAGE_OR_BLOG_HEADING; ?></div><div class="help_button" id="help_button" onClick="OpenHelpWindow();">&nbsp;</div></div>

<div id="delete_page">
	  <table align="center" border="0" width="80%"><tr><td>
        <table align="center" border="0"><tr>
        <td align="center">
        <p align="center"><?php echo DELETE_PAGE_OR_BLOG_SELECT_PAGE; ?>: 
            <select name="selectPageToDelete" id="selectPageToDelete" class="page_dropdown">
        <?php    
            $query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data ORDER BY page_name";
            $result = $bwb_dbh->query($query);
            while ($row = $result->fetch(PDO::FETCH_ASSOC))
			{
                $page_name = $row["page_name"];
                echo "<option value='$page_name'>$page_name</option>";
            }
        ?>
            </select>
            </p>
          </td>
          </tr>
          <tr>
            <td align="center">
            <div class='button_console_delete' id="delete_page_btn" onClick="DeleteConfirm('page');"><span class='button_console_text_w_icon'><?php echo EDITOR_DELETE; ?></span></div>
            </td>
          </tr>
          </table>
 </td>
 <td>
      <table aign="center"><tr>
      <td align="center">
     <p align="center"><?php echo DELETE_PAGE_OR_BLOG_SELECT_BLOG; ?>: 
		<select name="selectBlogToDelete" id="selectBlogToDelete" class="page_dropdown">
		<?php
			$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "blogs WHERE `owner`='" . $userid . "' ORDER BY revised";
			$result = $bwb_dbh->query($query);
			$num_results = $result->rowCount();
			for ($i = 0; $i < $num_results; $i++)
			{
				$row = $result->fetch(PDO::FETCH_ASSOC);
				$blog_id = $row["id"];
				$blog_page = $row["page_name"];
				$blog_revised = $row["revised"];
				if ($blog_id == $last_blog_edited)
					$selected = " selected='selected'";
				else
					$selected = "";
				
				echo "<option value='" . $blog_id . "'" . $selected . ">" . $blog_page . " " . $blog_revised . "</option>";
			}
			
		?>
		</select>
        </p>
        </td>
        </tr>
        <tr>
            <td align="center">
            <div class='button_console_delete' id="delete_blog_btn" onClick="DeleteConfirm('blog');"><span class='button_console_text_w_icon'><?php echo EDITOR_DELETE; ?></span></div>
            </td>
          </tr>
		</table>
   </td></tr></table>
      </div>
      
  <?php include("lib/popup_msg.html"); ?>
      
<script language="JavaScript"  type="text/javascript">
	popup_msg.HidePopupMsg();
</script>
</body>
</html>

==> breeze_website_builder_6.6.18.tar.gz: manage/delete_page_select.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 9/9/2008
// Revised: 2/10/2012	ELL
// Added table prefix handling.
	
	include ("check_session.php");
?>
<!DOCTYPE html>
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>Delete Page Select | Breeze Website Builder</title>
<link rel="stylesheet" href="theme/<?php echo $theme; ?>/manager.css" type="text/css">

<style type="text/css">
#help_button	{	
	position:relative;
	display:block;
	top:-15px;
	left:215px;
	height:31px;
	width:31px;
	z-index:100;
}
#delete_page_btn	{	width:110px;	}
#delete_blog_btn	{	width:110px;	}
</style>

<script language="javascript" type="text/javascript" src="js/browser_detect.js"></script>
<script language="javascript" type="text/javascript" src="js/mouse_position.js"></script>
<script language="javascript" type="text/javascript" src="js/popup_msg.js"></script>
<script language="javascript" type="text/javascript" src="js/delete_page_select.js"></script>

<script>
<?php
	echo "	var YES_WORD = \"" . YES_WORD . "\";\n";
	echo "	var NO_WORD = \"" . NO_WORD . "\";\n";
	echo "	var DELETE_PAGE_OR_BLOG_DELETE_BLOG_CONFIRM_1_MSG = \"" . DELETE_PAGE_OR_BLOG_DELETE_BLOG_CONFIRM_1_MSG . "\";\n";
	echo "	var DELETE_PAGE_OR_BLOG_DELETE_BLOG_CONFIRM_2_MSG = \"" . DELETE_PAGE_OR_BLOG_DELETE_BLOG_CONFIRM_2_MSG . "\";\n";
	echo "	var DELETE_PAGE_OR_BLOG_DELETE_PAGE_CONFIRM_1_MSG = \"" . DELETE_PAGE_OR_BLOG_DELETE_PAGE_CONFIRM_1_MSG . "\";\n";
	echo "	var DELETE_PAGE_OR_BLOG_DELETE_PAGE_CONFIRM_2_MSG = \"" . DELETE_PAGE_OR_BLOG_DELETE_PAGE_CONFIRM_2_MSG . "\";\n";
	echo "	var DELETE_PAGE_OR_BLOG_RECALL_PLUGIN_CONFIRM_1_MSG = \"" . DELETE_PAGE_OR_BLOG_RECALL_PLUGIN_CONFIRM_1_MSG . "\";\n";
	echo "	var DELETE_PAGE_OR_BLOG_RECALL_PLUGIN_CONFIRM_2_MSG = \"" . DELETE_PAGE_OR_BLOG_RECALL_PLUGIN_CONFIRM_2_MSG . "\";\n";
	
	echo "	var BWB_BASE_DIR = \"" . BWB_BASE_DIR . "\";\n";
	echo "	var BWB_WEBPAGE_DIR = \"" . BWB_WEBPAGE_DIR . "\";\n";
	
	echo "	var http = '$http';\n";
?>
</script>
</head>

<body>
<div class="button_heading_sub_level_1" id="delete_page_blog_heading"><div class="button_heading_text_sub_level_1"><?php echo DELETE_PAGE_OR_BLOG_HEADING; ?></div><div class="help_button" id="help_button" onClick="OpenHelpWindow();">&nbsp;</div></div>

<div id="delete_page">
	  <table align="center" border="0" width="80%"><tr><td>
        <table align="center" border="0"><tr>
        <td align="center">
        <p align="center"><?php echo DELETE_PAGE_OR_BLOG_SELECT_PAGE; ?>: 
            <select name="selectPageToDelete" id="selectPageToDelete" class="page_dropdown">
        <?php    
            $query = "SELECT page_name, active FROM " . BWB_TABLE_PREFIX . "page_data ORDER BY page_name";
            $result = $bwb_dbh->query($query);
            while ($row = $result->fetch(PDO::FETCH_ASSOC))
			{
                $page_name = $row["page_name"];
				$active = $row['active'];
				if  ($active < 1)
					$active_str = " (" . INACTIVE_WORD . ")";
				else
					$active_str = "";
                echo "<option value='$page_name'>$page_name$active_str</option>";
            }
        ?>
            </select>
            </p>
          </td>
          </tr>
          <tr>
            <td align="center">
            <div class='button_console_delete' id="delete_page_btn" onClick="DeleteConfirm('page');"><span class='button_console_text_w_icon'><?php echo EDITOR_DELETE; ?></span></div>
            </td>
          </tr>
          </table>
 </td>
 <td>
      <table aign="center"><tr>
      <td align="center">
     <p align="center"><?php echo DELETE_PAGE_OR_BLOG_SELECT_BLOG; ?>: 
		<select name="selectBlogToDelete" id="selectBlogToDelete" class="page_dropdown">
		<?php
			$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "blogs WHERE `owner`='" . $userid . "' ORDER BY revised";
			$result = $bwb_dbh->query($query);
			$num_results = $result->rowCount();
			for ($i = 0; $i < $num_results; $i++)
			{
				$row = $result->fetch(PDO::FETCH_ASSOC);
				$blog_id = $row["id"];
				$blog_page = $row["page_name"];
				$blog_revised = $row["revised"];
				if ($blog_id == $last_blog_edited)
					$selected = " selected='selected'";
				else
					$selected = "";
				
				echo "<option value='" . $blog_id . "'" . $selected . ">" . $blog_page . " " . $blog_revised . "</option>";
			}
			
		?>
		</select>
        </p>
        </td>
        </tr>
        <tr>
            <td align="center">
            <div class='button_console_delete' id="delete_blog_btn" onClick="DeleteConfirm('blog');"><span class='button_console_text_w_icon'><?php echo EDITOR_DELETE; ?></span></div>
            </td>
          </tr>
		</table>
   </td></tr></table>
      </div>
      
  <?php include("lib/popup_msg.html"); ?>
      
<script language="JavaScript"  type="text/javascript">
	popup_msg.HidePopupMsg();
</script>
</body>
</html>
